/**
 * 政策
 */

import moment = require("moment");
import { OPERATIONALDATATYPE, TABLEID, TABLENAME } from "../config/enum/dbEnum";
import { ERRORENUM } from "../config/enum/errorEnum";
import { operationalData, selectData } from "../data/operationalData";
import { getMySqlMs, randomId } from "../tools/system";
import { BizError } from "../util/bizError";
import { eccFormParam } from "../util/verificationParam";
import { PolicyUpdateConfig } from "../config/eccParam/enterprise";


export async function enterprisePolicyList(keywords:string, page:number) {
    let selectParam:any = {};
    if (keywords) selectParam.desc = {"%like%":keywords};
    let filesList = ["poId", "title", "source", "createTimeMs", "closeTimeMs", "isPermanent"];
    let resList = await selectData(OPERATIONALDATATYPE.分页查询, TABLENAME.政策表, selectParam, filesList, page);
    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.政策表, selectParam, null);

    let dataList = []; 
    resList.forEach(info => {
        dataList.push({
            poId:info.poId,
            title:info.title,
            source:info.source,
            createTimeMs:info.createTimeMs,
            closeTimeMs:info.closeTimeMs,
            isPermanent:info.isPermanent
        });
    });

    return {dataList, dataCount};
}


export async function enterprisePolicyInfo(poId:string) {
    let filesList = ["poId", "title", "source", "createTimeMs", "closeTimeMs", "isPermanent", "coverImg", "desc"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.政策表, {poId}, filesList);

    let dataInfo = {
        title:resInfo.title,
        source:resInfo.source,
        desc:resInfo.desc,
        coverImg:resInfo.coverImg ?  JSON.parse(resInfo.coverImg) : [],
        closeTimeMs:new Date(resInfo.closeTimeMs).valueOf(),
        isPermanent:resInfo.isPermanent
    };
    

    return {dataInfo};
}



export async function enterprisePolicyUpdate(poId:string, param) {
    const FuncName = "修改政策表"
    eccFormParam(FuncName, PolicyUpdateConfig, param );
    let filesList = ["poId", "title", "desc", "source", "coverImg", "closeTimeMs", "isPermanent"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.政策表, {poId}, filesList);
    if (!resInfo || !resInfo.poId) throw new BizError(ERRORENUM.数据不存在);

    param.closeTimeMs = getMySqlMs(param.closeTimeMs);
    if (!param.coverImg) param.coverImg = '[]';
    else param.coverImg = JSON.stringify(param.coverImg);
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.政策表, param, {poId});

    return {isSuccess:true};
}

export async function enterprisePolicyAdd( param) {
    const FuncName = "添加政策表"
    eccFormParam(FuncName, PolicyUpdateConfig, param );
  
    param.closeTimeMs = getMySqlMs(param.closeTimeMs);
    param.createTimeMs = getMySqlMs();
    if (!param.coverImg) param.coverImg = '[]';
    else param.coverImg = JSON.stringify(param.coverImg);
    param.poId = randomId(TABLEID.政策表);
    await operationalData(OPERATIONALDATATYPE.增加, TABLENAME.政策表, param, {});

    return {isSuccess:true};
}


export async function enterprisePolicyDelete(poId:string) {
    let filesList = ["poId"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.政策表, {poId}, filesList);
    if (!resInfo || !resInfo.poId) throw new BizError(ERRORENUM.数据不存在);

    await operationalData(OPERATIONALDATATYPE.删除, TABLENAME.政策表, {}, {poId});

    return {isSuccess:true};
}